##  Configuration
Configure an automation in the Automations section of the administration area.
Automation Parameters Parameter | Configuration
---|---
Trigger (When) |
  * Fact Sheet Type: Application
  * Event: Field value is changed
  * Field: Lifecycle


Conditions (If) | Configure optional conditions for the automation.
Action (Then) | Run Script: See the sample code provided below.


